==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesZa.php <==
<?php
/** Zhuang (Vahcuengh)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Biŋhai
 * @author Hakka
 */

$fallback = 'zh-hans';

$messages = array(
'underline-never' => 'coengz mbouj swjyungh',

# Dates
'sunday'        => 'Swnggeiz Yaet',
'monday'        => 'Swnggeiz Wtx',
'tuesday'       => 'Swnggeiz Yeih',
'wednesday'     => 'Swnggeiz Sam',
'thursday'      => 'Swnggeiz Seiq',
'friday'        => 'Swnggeiz Haj',
'saturday'      => 'Swnggeiz Lokj',
'sun'           => 'Ngoenz',
'mon'           => 'It',
'tue'           => 'Ngeih',
'wed'           => 'Sam',
'thu'           => 'Seiq',
'fri'           => 'Ngux',
'sat'           => 'Loeg',
'january'       => 'Nin Wtj',
'february'      => 'Nin Yeih',
'march'         => 'Nin Sam',
'april'         => 'Nin Seiq',
'may_long'      => 'Nin Haj',
'june'          => 'Nin Loekj',
'july'          => 'Nin Caet',
'august'        => 'Nin Betq',
'september'     => 'Nin Gouj',
'october'       => 'Nin Cwbx',
'november'      => 'Nin Cwbx Wtj',
'december'      => 'Nin Cwbx Yeih',
'january-gen'   => 'It nyied',
'february-gen'  => 'Ngeih nyied',
'march-gen'     => 'Sam nyied',
'april-gen'     => 'Seiq nyied',
'may-gen'       => 'Nin Haj',
'june-gen'      => 'Loeg nyied',
'july-gen'      => 'Caet nyied',
'august-gen'    => 'Bet nyied',
'september-gen' => 'Nin Gouj',
'october-gen'   => 'Cib nyied',
'november-gen'  => 'Cibit nyied',
'december-gen'  => 'Cibngeih nyied',
'jan'           => 'Itnyied',
'feb'           => 'Ngeihnyied',
'mar'           => 'Samnyied',
'apr'           => 'Seiqnyied',
'may'           => 'Nguxnyied',
'jun'           => 'Loegnyied',
'jul'           => 'Caetnyied',
'aug'           => 'Batnyied',
'sep'           => 'Goujnyied',
'oct'           => 'Cibnyied',
'nov'           => "Cib'itnyied",
'dec'           => 'Cibngeihnyied',

# Categories related messages
'pagecategories' => '{{PLURAL:$1$1 aen|faendingz|faendingz}}',
'subcategories'  => 'Faendingz lwgsai',

'about'          => 'Gvendaengz',
'article'        => 'Banjbienj',
'cancel'         => 'Fwtqfex',
'qbfind'         => 'Ra',
'qbedit'         => 'Gaij',
'qbmyoptions'    => 'Yieb gou',
'qbspecialpages' => 'Doenghmae daegxsei',
'mytalk'         => 'Gaeq gou gangj',
'navigation'     => 'Dazzaeuh',

'errorpagetitle'   => 'Loengloek',
'tagline'          => 'okcih {{SITENAME}}',
'help'             => 'Bangcoh',
'search'           => 'Cwmh',
'searchbutton'     => 'Cwmh',
'go'               => 'Bae',
'searcharticle'    => 'Bae',
'history'          => 'Lizsij',
'history_short'    => 'Lizsij',
'printableversion' => 'Gojyaenq banj',
'permalink'        => 'Gaeq-lamh kaemdaengz',
'edit'             => 'gaij',
'create'           => 'Laeb',
'delete'           => 'Duz',
'protect'          => 'Hahdiuz',
'protect_change'   => 'gaij',
'newpage'          => 'Bienj moq',
'talkpage'         => 'Dunjlun yieb neix',
'talkpagelinktext' => 'Daujlun',
'personaltools'    => 'Hongdawz bonjfaenh',
'talk'             => 'Kwng',
'views'            => 'Cazyawj',
'toolbox'          => 'Loengx hong',
'jumpto'           => 'Diuq bae',
'jumptonavigation' => 'Dazzaeuh',
'jumptosearch'     => 'Ra',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Gvanhyih {{SITENAME}}',
'aboutpage'            => 'Project:gvanhyih',
'currentevents'        => 'Saehgienh seizneix',
'disclaimers'          => 'gangjmingz mienxcwz',
'disclaimerpage'       => 'Project:Itbuen mienxcwz',
'edithelp'             => 'Caeuq mungz san-zonz',
'edithelppage'         => 'Help:gaij',
'faq'                  => 'Cam caeuq dap',
'faqpage'              => 'Project:Cam caeuq dap',
'helppage'             => 'Help:moegloeg',
'mainpage'             => 'Yiebdaeuz',
'mainpage-description' => 'Yiebdeauz',
'policy-url'           => 'Project:fuengcim',
'portal'               => 'Segih',
'portal-url'           => 'Project:seqgih',
'privacy'              => 'Seiyaem cwngcwz',
'privacypage'          => 'Project:Seiyaem cwngcwz',

'badaccess'        => 'Loengloek gienzhanh',
'badaccess-group0' => 'Cingjgouz mwngz mbouj haengj ciuqguh.',
'badaccess-groups' => 'Cingjgouz mwngz hanh youq {{PLURAL:$2|neix|gijneix}} bouxyungh: $1',

'versionrequired'     => 'Sihyau MediaWiki $1',
'versionrequiredtext' => 'Sihyau MediaWik $1 caengj daeng sawjyungh.',

'youhavenewmessages' => 'Mungz meiz $1（$2）。',
'editsection'        => 'gaij',
'editold'            => 'gaij',
'editlink'           => 'gaij',
'editsectionhint'    => 'Gaij duenh:$1',
'showtoc'            => "yienh'ok",
'hidetoc'            => 'cangz',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Feanzcieng',
'nstab-user'      => 'Yieb bouxsawjyungq',
'nstab-project'   => 'Yieb giva',
'nstab-image'     => 'Vwnzgen',
'nstab-mediawiki' => 'Siuhsik',
'nstab-template'  => 'Mozbanj',
'nstab-help'      => 'Yieb bangcoh',
'nstab-category'  => 'Faendingz',

# General errors
'viewsource' => 'Liuq lagh mae-nej',

# Login and logout pages
'yourname'                => 'Ciu bouxdeiz:',
'yourpassword'            => 'Mizmak：',
'login'                   => 'Dwnghluz',
'nav-login-createaccount' => 'dwngh haeuj/laebbaen canghu',
'userlogin'               => 'Daengh haeuj/Laeb bouxdeiz',
'logout'                  => 'Doiq ok',
'userlogout'              => 'Doiq ok',
'notloggedin'             => 'Maengx laezhaej',
'nologinlink'             => 'Laeb bouxdeiz',
'username'                => 'Ciu bouxdeiz:',

# Edit pages
'summary'            => 'Saegmangj:',
'minoredit'          => 'Di-nej gaij noix',
'watchthis'          => 'Gamyawj yieb neix',
'savearticle'        => 'Zonzdiuz mae-nej',
'showpreview'        => 'Okqhaej piu-ngoengx',
'showdiff'           => 'Okqhaej gaeqgaei',
'whitelistedittitle' => 'Laezdiuz haeuj aiq naej san-zonz',
'newarticle'         => '（Moq）',

# Diffs
'editundo' => 'siu',

# Search results
'searchresults'             => 'gietgoj ra',
'searchresults-title'       => 'doiq "$1" gij gietgoj ra',
'search-interwiki-more'     => '（more）',
'search-mwsuggest-enabled'  => 'miz genyi',
'search-mwsuggest-disabled' => 'mbouj miz genyi',
'powersearch'               => 'Cwmh goeggiz',
'powersearch-legend'        => 'Gauhgiz saeu',
'powersearch-redir'         => 'Cungzdinghyiengq liedbiuj',

# Preferences page
'mypreferences'     => 'Doenghgaeq gou hae',
'prefsnologin'      => 'Maengx laezhaej',
'searchresultshead' => 'Cwmh',

'group-user-member' => 'Bouxsawjyungq',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'gaij yieb neix',

# Recent changes
'recentchanges'   => 'Gaeqgaij seizneix',
'diff'            => 'Faenbied',
'hide'            => 'Cangz',
'show'            => "Yienh'ok",
'minoreditletter' => 'n',
'newpageletter'   => 'M',
'boteditletter'   => 'g',

# Recent changes linked
'recentchangeslinked' => 'Lienh ok gaengaij',

# Upload
'upload'            => 'Cienz vwnzgen',
'uploadnologin'     => 'Maengx laezhaej',
'filedesc'          => 'Saegmangj',
'fileuploadsummary' => 'Saegmangj:',
'uploadedimage'     => 'senq cienz "[[$1]]"',
'watchthisupload'   => 'Demq mae-nej',

# Special:ListFiles
'listfiles_user' => 'Bouxyungh',

# File description page
'filehist-current'  => 'seizneix',
'filehist-datetime' => 'Ngoenz/Seizgan',
'filehist-user'     => 'Bouxsawjyungh',
'filehist-comment'  => 'Gejgangj',

# Random page
'randompage' => 'Mae zaihzex',

# Statistics
'statistics-pages' => 'Yieb',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|cihciet|cihciet}}',
'newpages'          => 'Yieb moq',
'newpages-username' => 'Ciu bouxdeiz:',
'move'              => 'Daen',
'movethispage'      => 'Caen mae nej',

# Book sources
'booksources-go' => 'Bae',

# Special:Log
'log' => 'Ngoenzceiq',

# Special:AllPages
'allpages'       => 'Sojmiz yieb',
'allarticles'    => 'Sojmiz yieb',
'allpagessubmit' => 'Bae',

# Watchlist
'watchlist'     => 'Yieb gou yawj',
'mywatchlist'   => 'Gaeq gou demq',
'watchnologin'  => 'Maengx laezhaej',
'watch'         => 'Demq',
'watchthispage' => 'Demq mae-nej',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Bawxndu……',
'unwatching' => 'Souma bawxndu……',

# Protect
'prot_1movedto2' => '[[$1]] caen bei [[$2]]',

# Restrictions (nouns)
'restriction-move' => 'Caen',

# Namespace form on various pages
'namespace'      => 'ndawhoengq mingzcih:',
'blanknamespace' => '（Cujyau）',

# Contributions
'contributions' => 'Gaeq bouxdeiz haej',
'mycontris'     => 'Gaeq gou haej',
'uctop'         => '（dingz）',

'sp-contributions-submit' => 'Ra',

# What links here
'whatlinkshere'      => 'Maelaez lamh haenznej',
'whatlinkshere-page' => 'Yieb：',

# Block/unblock
'ipblocklist-submit' => 'Cwmh',
'contribslink'       => "gung'yen",

# Move page
'move-page-legend' => 'Caen doengh mae',
'movearticle'      => 'Caen doengh mae:',
'movenologin'      => 'Maengx laezhaej',
'move-watch'       => 'Demq mae-nej',
'movepagebtn'      => 'Caen doengh mae',
'movedto'          => 'Caen bei',
'1movedto2'        => '[[$1]] caen bei [[$2]]',
'movereason'       => 'Haujgaemj',
'revertmove'       => 'siu',

# Tooltip help for the actions
'tooltip-pt-mytalk'      => 'Yieb daujlun mwngz',
'tooltip-pt-preferences' => 'Doenghgaeq gou hae',
'tooltip-pt-logout'      => 'Doiq ok',
'tooltip-ca-talk'        => 'Gvanhyih cingqfaenz yieb gij daojun',
'tooltip-ca-history'     => 'yieb neix gij banj lizsij',
'tooltip-ca-move'        => 'Dean yieb neix',
'tooltip-search'         => 'Ra {{SITENAME}}',
'tooltip-p-logo'         => 'Mae meh',
'tooltip-n-mainpage'     => 'Raen Yiebdaeuz',
'tooltip-n-randompage'   => 'Cang haeuj yieb seizgih',
'tooltip-n-help'         => 'Cimh gouz bangcoh',
'tooltip-t-upload'       => 'Cienz vwnzgen',
'tooltip-ca-nstab-main'  => 'Cazyawj ndawyungz yieb',

# Special:NewFiles
'ilsubmit' => 'Cwmh',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'cenzbu',
'namespacesall' => 'cenzbu',
'monthsall'     => 'cenzbu',

# Multipage image navigation
'imgmultigo' => 'Bei！',

# Table pager
'table_pager_limit_submit' => 'Bei',

# Watchlist editing tools
'watchlisttools-view' => 'Cazyawj gaij mizgven',

# Special:SpecialPages
'specialpages' => 'Doenghmae daegxsei',

# Special:Tags
'tags-edit' => 'gaij',

);

==> mediawiki-1.18.5.tbz: www/mediawiki/languages/messages/MessagesZa.php <==
<?php
/** Zhuang (Vahcuengh)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Biŋhai
 * @author Hakka
 */

$fallback = 'zh-hans';

$messages = array(
'underline-never' => 'coengz mbouj swjyungh',

# Dates
'sunday'        => 'Swnggeiz Yaet',
'monday'        => 'Swnggeiz Wtx',
'tuesday'       => 'Swnggeiz Yeih',
'wednesday'     => 'Swnggeiz Sam',
'thursday'      => 'Swnggeiz Seiq',
'friday'        => 'Swnggeiz Haj',
'saturday'      => 'Swnggeiz Lokj',
'sun'           => 'Ngoenz',
'mon'           => 'It',
'tue'           => 'Ngeih',
'wed'           => 'Sam',
'thu'           => 'Seiq',
'fri'           => 'Ngux',
'sat'           => 'Loeg',
'january'       => 'Nin Wtj',
'february'      => 'Nin Yeih',
'march'         => 'Nin Sam',
'april'         => 'Nin Seiq',
'may_long'      => 'Nin Haj',
'june'          => 'Nin Loekj',
'july'          => 'Nin Caet',
'august'        => 'Nin Betq',
'september'     => 'Nin Gouj',
'october'       => 'Nin Cwbx',
'november'      => 'Nin Cwbx Wtj',
'december'      => 'Nin Cwbx Yeih',
'january-gen'   => 'It nyied',
'february-gen'  => 'Ngeih nyied',
'march-gen'     => 'Sam nyied',
'april-gen'     => 'Seiq nyied',
'may-gen'       => 'Nin Haj',
'june-gen'      => 'Loeg nyied',
'july-gen'      => 'Caet nyied',
'august-gen'    => 'Bet nyied',
'september-gen' => 'Nin Gouj',
'october-gen'   => 'Cib nyied',
'november-gen'  => 'Cibit nyied',
'december-gen'  => 'Cibngeih nyied',
'jan'           => 'Itnyied',
'feb'           => 'Ngeihnyied',
'mar'           => 'Samnyied',
'apr'           => 'Seiqnyied',
'may'           => 'Nguxnyied',
'jun'           => 'Loegnyied',
'jul'           => 'Caetnyied',
'aug'           => 'Batnyied',
'sep'           => 'Goujnyied',
'oct'           => 'Cibnyied',
'nov'           => "Cib'itnyied",
'dec'           => 'Cibngeihnyied',

# Categories related messages
'pagecategories' => '{{PLURAL:$1$1 aen|faendingz|faendingz}}',
'subcategories'  => 'Faendingz lwgsai',

'about'      => 'Gvendaengz',
'article'    => 'Banjbienj',
'cancel'     => 'Fwtqfex',
'mytalk'     => 'Gaeq gou gangj',
'navigation' => 'Dazzaeuh',

# Cologne Blue skin
'qbfind'         => 'Ra',
'qbedit'         => 'Gaij',
'qbmyoptions'    => 'Yieb gou',
'qbspecialpages' => 'Doenghmae daegxsei',
'faq'            => 'Cam caeuq dap',
'faqpage'        => 'Project:Cam caeuq dap',

# Vector skin
'vector-action-delete'  => 'Ca',
'vector-action-move'    => 'Daen',
'vector-action-protect' => 'Bauj',
'vector-view-create'    => 'Laeb',
'vector-view-edit'      => 'gaij',
'vector-view-history'   => 'Cazyawj lizsij',

'errorpagetitle'   => 'Loengloek',
'tagline'          => 'okcih {{SITENAME}}',
'help'             => 'Bangcoh',
'search'           => 'Cwmh',
'searchbutton'     => 'Cwmh',
'go'               => 'Bae',
'searcharticle'    => 'Bae',
'history'          => 'Lizsij',
'history_short'    => 'Lizsij',
'printableversion' => 'Gojyaenq banj',
'permalink'        => 'Gaeq-lamh kaemdaengz',
'edit'             => 'gaij',
'create'           => 'Laeb',
'delete'           => 'Duz',
'protect'          => 'Hahdiuz',
'protect_change'   => 'gaij',
'newpage'          => 'Bienj moq',
'talkpage'         => 'Dunjlun yieb neix',
'talkpagelinktext' => 'Daujlun',
'personaltools'    => 'Hongdawz bonjfaenh',
'talk'             => 'Kwng',
'views'            => 'Cazyawj',
'toolbox'          => 'Loengx hong',
'jumpto'           => 'Diuq bae',
'jumptonavigation' => 'Dazzaeuh',
'jumptosearch'     => 'Ra',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Gvanhyih {{SITENAME}}',
'aboutpage'            => 'Project:gvanhyih',
'currentevents'        => 'Saehgienh seizneix',
'disclaimers'          => 'gangjmingz mienxcwz',
'disclaimerpage'       => 'Project:Itbuen mienxcwz',
'edithelp'             => 'Caeuq mungz san-zonz',
'edithelppage'         => 'Help:gaij',
'helppage'             => 'Help:moegloeg',
'mainpage'             => 'Yiebdaeuz',
'mainpage-description' => 'Yiebdeauz',
'policy-url'           => 'Project:fuengcim',
'portal'               => 'Segih',
'portal-url'           => 'Project:seqgih',
'privacy'              => 'Seiyaem cwngcwz',
'privacypage'          => 'Project:Seiyaem cwngcwz',

'badaccess'        => 'Loengloek gienzhanh',
'badaccess-group0' => 'Cingjgouz mwngz mbouj haengj ciuqguh.',
'badaccess-groups' => 'Cingjgouz mwngz hanh youq {{PLURAL:$2|neix|gijneix}} bouxyungh: $1',

'versionrequired'     => 'Sihyau MediaWiki $1',
'versionrequiredtext' => 'Sihyau MediaWik $1 caengj daeng sawjyungh.',

'youhavenewmessages' => 'Mungz meiz $1（$2）。',
'editsection'        => 'gaij',
'editold'            => 'gaij',
'editlink'           => 'gaij',
'editsectionhint'    => 'Gaij duenh:$1',
'showtoc'            => "yienh'ok",
'hidetoc'            => 'cangz',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Feanzcieng',
'nstab-user'      => 'Yieb bouxsawjyungq',
'nstab-project'   => 'Yieb giva',
'nstab-image'     => 'Vwnzgen',
'nstab-mediawiki' => 'Siuhsik',
'nstab-template'  => 'Mozbanj',
'nstab-help'      => 'Yieb bangcoh',
'nstab-category'  => 'Faendingz',

# General errors
'viewsource' => 'Liuq lagh mae-nej',

# Login and logout pages
'yourname'                => 'Ciu bouxdeiz:',
'yourpassword'            => 'Mizmak：',
'login'                   => 'Dwnghluz',
'nav-login-createaccount' => 'dwngh haeuj/laebbaen canghu',
'userlogin'               => 'Daengh haeuj/Laeb bouxdeiz',
'logout'                  => 'Doiq ok',
'userlogout'              => 'Doiq ok',
'notloggedin'             => 'Maengx laezhaej',
'nologinlink'             => 'Laeb bouxdeiz',

# Edit pages
'summary'            => 'Saegmangj:',
'minoredit'          => 'Di-nej gaij noix',
'watchthis'          => 'Gamyawj yieb neix',
'savearticle'        => 'Zonzdiuz mae-nej',
'showpreview'        => 'Okqhaej piu-ngoengx',
'showdiff'           => 'Okqhaej gaeqgaei',
'whitelistedittitle' => 'Laezdiuz haeuj aiq naej san-zonz',
'newarticle'         => '（Moq）',

# Diffs
'editundo' => 'siu',

# Search results
'searchresults'             => 'gietgoj ra',
'searchresults-title'       => 'doiq "$1" gij gietgoj ra',
'search-interwiki-more'     => '（more）',
'search-mwsuggest-enabled'  => 'miz genyi',
'search-mwsuggest-disabled' => 'mbouj miz genyi',
'powersearch'               => 'Cwmh goeggiz',
'powersearch-legend'        => 'Gauhgiz saeu',
'powersearch-redir'         => 'Cungzdinghyiengq liedbiuj',

# Preferences page
'mypreferences'     => 'Doenghgaeq gou hae',
'prefsnologin'      => 'Maengx laezhaej',
'searchresultshead' => 'Cwmh',
'username'          => 'Ciu bouxdeiz:',

'group-user-member' => '{{GENDER:$1|Bouxsawjyungq}}',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'gaij yieb neix',

# Recent changes
'recentchanges'   => 'Gaeqgaij seizneix',
'diff'            => 'Faenbied',
'hide'            => 'Cangz',
'show'            => "Yienh'ok",
'minoreditletter' => 'n',
'newpageletter'   => 'M',
'boteditletter'   => 'g',

# Recent changes linked
'recentchangeslinked' => 'Lienh ok gaengaij',

# Upload
'upload'            => 'Cienz vwnzgen',
'uploadnologin'     => 'Maengx laezhaej',
'filedesc'          => 'Saegmangj',
'fileuploadsummary' => 'Saegmangj:',
'uploadedimage'     => 'senq cienz "[[$1]]"',
'watchthisupload'   => 'Demq mae-nej',

# Special:ListFiles
'listfiles_user' => 'Bouxyungh',

# File description page
'filehist-current'  => 'seizneix',
'filehist-datetime' => 'Ngoenz/Seizgan',
'filehist-user'     => 'Bouxsawjyungh',
'filehist-comment'  => 'Gejgangj',

# Random page
'randompage' => 'Mae zaihzex',

# Statistics
'statistics-pages' => 'Yieb',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|cihciet|cihciet}}',
'newpages'          => 'Yieb moq',
'newpages-username' => 'Ciu bouxdeiz:',
'move'              => 'Daen',
'movethispage'      => 'Caen mae nej',

# Book sources
'booksources-go' => 'Bae',

# Special:Log
'log' => 'Ngoenzceiq',

# Special:AllPages
'allpages'       => 'Sojmiz yieb',
'allarticles'    => 'Sojmiz yieb',
'allpagessubmit' => 'Bae',

# Watchlist
'watchlist'     => 'Yieb gou yawj',
'mywatchlist'   => 'Gaeq gou demq',
'watchnologin'  => 'Maengx laezhaej',
'watch'         => 'Demq',
'watchthispage' => 'Demq mae-nej',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Bawxndu……',
'unwatching' => 'Souma bawxndu……',

# Protect
'prot_1movedto2' => '[[$1]] caen bei [[$2]]',

# Restrictions (nouns)
'restriction-move' => 'Caen',

# Namespace form on various pages
'namespace'      => 'ndawhoengq mingzcih:',
'blanknamespace' => '（Cujyau）',

# Contributions
'contributions' => 'Gaeq bouxdeiz haej',
'mycontris'     => 'Gaeq gou haej',
'uctop'         => '（dingz）',

'sp-contributions-submit' => 'Ra',

# What links here
'whatlinkshere'      => 'Maelaez lamh haenznej',
'whatlinkshere-page' => 'Yieb：',

# Block/unblock
'ipblocklist-submit' => 'Cwmh',
'contribslink'       => "gung'yen",

# Move page
'move-page-legend' => 'Caen doengh mae',
'movearticle'      => 'Caen doengh mae:',
'movenologin'      => 'Maengx laezhaej',
'move-watch'       => 'Demq mae-nej',
'movepagebtn'      => 'Caen doengh mae',
'movedto'          => 'Caen bei',
'1movedto2'        => '[[$1]] caen bei [[$2]]',
'movereason'       => 'Haujgaemj',
'revertmove'       => 'siu',

# Tooltip help for the actions
'tooltip-pt-mytalk'      => 'Yieb daujlun mwngz',
'tooltip-pt-preferences' => 'Doenghgaeq gou hae',
'tooltip-pt-logout'      => 'Doiq ok',
'tooltip-ca-talk'        => 'Gvanhyih cingqfaenz yieb gij daojun',
'tooltip-ca-history'     => 'yieb neix gij banj lizsij',
'tooltip-ca-move'        => 'Dean yieb neix',
'tooltip-search'         => 'Ra {{SITENAME}}',
'tooltip-p-logo'         => 'Mae meh',
'tooltip-n-mainpage'     => 'Raen Yiebdaeuz',
'tooltip-n-randompage'   => 'Cang haeuj yieb seizgih',
'tooltip-n-help'         => 'Cimh gouz bangcoh',
'tooltip-t-upload'       => 'Cienz vwnzgen',
'tooltip-ca-nstab-main'  => 'Cazyawj ndawyungz yieb',

# Special:NewFiles
'ilsubmit' => 'Cwmh',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'cenzbu',
'namespacesall' => 'cenzbu',
'monthsall'     => 'cenzbu',

# Multipage image navigation
'imgmultigo' => 'Bei！',

# Table pager
'table_pager_limit_submit' => 'Bei',

# Watchlist editing tools
'watchlisttools-view' => 'Cazyawj gaij mizgven',

# Special:SpecialPages
'specialpages' => 'Doenghmae daegxsei',

# Special:Tags
'tags-edit' => 'gaij',

);
